@@ -136,7 +136,7 @@ class ShapRFECV(BaseFitComputePlotClass):
             min_features_to_select (int, optional):
                 Minimum number of features to be kept. This is a stopping criterion of the feature elimination. By
                 default the process stops when one feature is left. If columns_to_keep is specified in the fit method,
-                it may overide this parameter to the maximum between length of columns_to_keep the two.
+                it may override this parameter to the maximum between length of columns_to_keep the two.
 
             cv (int, cross-validation generator or an iterable, optional):
                 Determines the cross-validation splitting strategy. Compatible with sklearn
@@ -405,6 +405,8 @@ class ShapRFECV(BaseFitComputePlotClass):
         sample_weight=None,
         columns_to_keep=None,
         column_names=None,
+        groups=None,
+        shap_variance_penalty_factor=None,
         **shap_kwargs,
     ):
         """
@@ -443,6 +445,18 @@ class ShapRFECV(BaseFitComputePlotClass):
                 feature names. If not provided the existing feature names are used or default feature names are
                 generated.
 
+            groups (pd.Series, np.ndarray, list, optional):
+                array-like of shape (n_samples,)
+                Group labels for the samples used while splitting the dataset into train/test set.
+                Only used in conjunction with a "Group" `cv` instance.
+                (e.g. `sklearn.model_selection.GroupKFold`).
+
+            shap_variance_penalty_factor (int or float, optional):
+                Apply aggregation penalty when computing average of shap values for a given feature.
+                Results in a preference for features that have smaller standard deviation of shap
+                values (more coherent shap importance). Recommend value 0.5 - 1.0.
+                Formula: penalized_shap_mean = (mean_shap - (std_shap * shap_variance_penalty_factor))
+
             **shap_kwargs:
                 keyword arguments passed to
                 [shap.Explainer](https://shap.readthedocs.io/en/latest/generated/shap.Explainer.html#shap.Explainer).
@@ -476,7 +490,7 @@ class ShapRFECV(BaseFitComputePlotClass):
             if all(x in column_names for x in list(X.columns)):
                 pass
             else:
-                raise (ValueError("The column names in parameter columns_to_keep and column_names are not macthing."))
+                raise (ValueError("The column names in parameter columns_to_keep and column_names are not matching."))
 
         # Check that the total number of columns to select is less than total number of columns in the data.
         # only when both parameters are provided.
@@ -487,6 +501,19 @@ class ShapRFECV(BaseFitComputePlotClass):
                     "Lower the value for min_features_to_select or number of columns in columns_to_keep"
                 )
 
+        # Check shap_variance_penalty_factor has acceptable value
+        if shap_variance_penalty_factor is None:
+            _shap_variance_penalty_factor = 0
+        elif (
+            isinstance(shap_variance_penalty_factor, float) or isinstance(shap_variance_penalty_factor, int)
+        ) and shap_variance_penalty_factor >= 0:
+            _shap_variance_penalty_factor = shap_variance_penalty_factor
+        else:
+            warnings.warn(
+                "shap_variance_penalty_factor must be None, int or float. " "Setting shap_variance_penalty_factor = 0"
+            )
+            _shap_variance_penalty_factor = 0
+
         self.X, self.column_names = preprocess_data(X, X_name="X", column_names=column_names, verbose=self.verbose)
         self.y = preprocess_labels(y, y_name="y", index=self.X.index, verbose=self.verbose)
         if sample_weight is not None:
@@ -519,9 +546,12 @@ class ShapRFECV(BaseFitComputePlotClass):
             # Get current dataset info
             current_features_set = remaining_features
             if columns_to_keep is None:
-                remaining_removeable_features = list(set(current_features_set))
+                # Keeps the original order, while removing duplicate elements
+                remaining_removeable_features = pd.Series(current_features_set).unique()
             else:
-                remaining_removeable_features = list(set(current_features_set) | set(columns_to_keep))
+                # Keeps the original order, while removing duplicate elements
+                remaining_removeable_features = pd.Series(list(current_features_set) + columns_to_keep).unique()
+
             current_X = self.X[remaining_removeable_features]
 
             # Set seed for results reproducibility
@@ -546,7 +576,7 @@ class ShapRFECV(BaseFitComputePlotClass):
                     sample_weight=sample_weight,
                     **shap_kwargs,
                 )
-                for train_index, val_index in self.cv.split(current_X, self.y)
+                for train_index, val_index in self.cv.split(current_X, self.y, groups)
             )
 
             shap_values = np.vstack([current_result[0] for current_result in results_per_fold])
@@ -555,13 +585,21 @@ class ShapRFECV(BaseFitComputePlotClass):
 
             # Calculate the shap features with remaining features and features to keep.
 
-            shap_importance_df = calculate_shap_importance(shap_values, remaining_removeable_features)
+            shap_importance_df = calculate_shap_importance(
+                shap_values, remaining_removeable_features, shap_variance_penalty_factor=_shap_variance_penalty_factor
+            )
 
             # Get features to remove
             features_to_remove = self._get_current_features_to_remove(
                 shap_importance_df, columns_to_keep=columns_to_keep
             )
-            remaining_features = list(set(current_features_set) - set(features_to_remove))
+            # Ensures the order of the first list is kept as it was originally,
+            # while removing elements which are present in both lists.
+            remaining_features = np.setdiff1d(
+                pd.Series(current_features_set).unique(),
+                pd.Series(features_to_remove).unique(),
+                assume_unique=True,
+            )
 
             # Report results
             self._report_current_results(
@@ -590,7 +628,7 @@ class ShapRFECV(BaseFitComputePlotClass):
         """
         Checks if fit() method has been run.
 
-        and computes the DataFrame with results of feature elimintation for each round.
+        and computes the DataFrame with results of feature elimination for each round.
 
         Returns:
             (pd.DataFrame):
@@ -600,7 +638,16 @@ class ShapRFECV(BaseFitComputePlotClass):
 
         return self.report_df
 
-    def fit_compute(self, X, y, sample_weight=None, columns_to_keep=None, column_names=None, **shap_kwargs):
+    def fit_compute(
+        self,
+        X,
+        y,
+        sample_weight=None,
+        columns_to_keep=None,
+        column_names=None,
+        shap_variance_penalty_factor=None,
+        **shap_kwargs,
+    ):
         """
         Fits the object with the provided data.
 
@@ -636,6 +683,12 @@ class ShapRFECV(BaseFitComputePlotClass):
                 feature names. If not provided the existing feature names are used or default feature names are
                 generated.
 
+            shap_variance_penalty_factor (int or float, optional):
+                Apply aggregation penalty when computing average of shap values for a given feature.
+                Results in a preference for features that have smaller standard deviation of shap
+                values (more coherent shap importance). Recommend value 0.5 - 1.0.
+                Formula: penalized_shap_mean = (mean_shap - (std_shap * shap_variance_penalty_factor))
+
             **shap_kwargs:
                 keyword arguments passed to
                 [shap.Explainer](https://shap.readthedocs.io/en/latest/generated/shap.Explainer.html#shap.Explainer).
@@ -654,17 +707,33 @@ class ShapRFECV(BaseFitComputePlotClass):
             sample_weight=sample_weight,
             columns_to_keep=columns_to_keep,
             column_names=column_names,
+            shap_variance_penalty_factor=shap_variance_penalty_factor,
             **shap_kwargs,
         )
         return self.compute()
 
-    def get_reduced_features_set(self, num_features):
+    def get_reduced_features_set(self, num_features, standard_error_threshold=1.0, return_type="feature_names"):
         """
         Gets the features set after the feature elimination process, for a given number of features.
 
         Args:
-            num_features (int):
-                Number of features in the reduced features set.
+            num_features (int or str):
+                If int: Number of features in the reduced features set.
+                If str: One of the following automatic num feature selection methods supported:
+                    1. best: strictly selects the num_features with the highest model score.
+                    2. best_coherent: For iterations that are within standard_error_threshold of the highest
+                    score, select the iteration with the lowest standard deviation of model score.
+                    3. best_parsimonious: For iterations that are within standard_error_threshold of the
+                    highest score, select the iteration with the fewest features.
+
+            standard_error_threshold (float):
+                If num_features is 'best_coherent' or 'best_parsimonious', this parameter is used.
+
+            return_type:
+                Accepts possible values of 'feature_names', 'support' or 'ranking'. These are defined as:
+                    1. feature_names: returns column names
+                    2. support: returns boolean mask
+                    3. ranking: returns numeric ranking of features
 
         Returns:
             (list of str):
@@ -672,6 +741,120 @@ class ShapRFECV(BaseFitComputePlotClass):
         """
         self._check_if_fitted()
 
+        if isinstance(num_features, str):
+            best_num_features = self._get_best_num_features(
+                best_method=num_features, standard_error_threshold=standard_error_threshold
+            )
+            if return_type == "feature_names":
+                return self._get_feature_names(best_num_features)
+            elif return_type == "support":
+                feature_names_selected = self._get_feature_names(best_num_features)
+                return self._get_feature_support(feature_names_selected)
+            elif return_type == "ranking":
+                return self._get_feature_ranking()
+
+        elif isinstance(num_features, int):
+            if return_type == "feature_names":
+                return self._get_feature_names(num_features)
+            elif return_type == "support":
+                feature_names_selected = self._get_feature_names(num_features)
+                return self._get_feature_support(feature_names_selected)
+            elif return_type == "ranking":
+                return self._get_feature_ranking()
+
+        else:
+            raise ValueError(
+                "Parameter num_features can be of type int, or of type str with"
+                "possible values of 'best', 'best_coherent' or 'best_parsimonious'"
+            )
+
+    def _get_best_num_features(self, best_method, standard_error_threshold=1.0):
+        """
+        Helper function to identify the best number of features to select as per some automatic
+        feature selection strategy. Strategies supported are:
+            1. best: strictly selects the num_features with the highest model score.
+            2. best_coherent: For iterations that are within standard_error_threshold of the highest
+            score, select the iteration with the lowest standard deviation of model score.
+            3. best_parsimonious: For iterations that are within standard_error_threshold of the
+            highest score, select the iteration with the fewest features.
+
+        Args:
+            best_method (str):
+                Automatic best feature selection strategy. One of "best", "best_coherent" or
+                "best_parsimonious".
+
+            standard_error_threshold (float):
+                Parameter used if best_method is 'best_coherent' or 'best_parsimonious'.
+                Numeric value greater than zero.
+
+        Returns:
+            (int)
+                num_features as per automatic feature selection strategy selected.
+        """
+
+        self._check_if_fitted()
+        shap_report = self.report_df.copy()
+
+        if (isinstance(standard_error_threshold, float) or isinstance(standard_error_threshold, int)) is not True:
+            raise ValueError("Parameter standard_error_threshold must be int or float")
+        elif standard_error_threshold < 0:
+            raise ValueError("Parameter standard_error_threshold must be >= zero.")
+
+        if best_method == "best":
+            shap_report["eval_metric"] = shap_report["val_metric_mean"]
+            best_iteration_idx = shap_report["eval_metric"].argmax()
+            best_num_features = shap_report["num_features"].iloc[best_iteration_idx]
+
+        elif best_method == "best_coherent":
+            shap_report["eval_metric"] = (
+                shap_report["val_metric_mean"] - shap_report["val_metric_std"] * standard_error_threshold
+            )
+            best_iteration_idx = shap_report["eval_metric"].argmax()
+            # Find standard error threshold above which we want to focus
+            best_val_metric_threshold = shap_report["eval_metric"].iloc[best_iteration_idx]
+            # Drop iterations with val_metric below threshold
+            shap_report = shap_report[shap_report["val_metric_mean"] >= best_val_metric_threshold]
+            # Get iteration with smallest val_metric_std
+            best_std_iteration_idx = shap_report["val_metric_std"].argmin()
+            best_num_features = shap_report["num_features"].iloc[best_std_iteration_idx]
+
+        elif best_method == "best_parsimonious":
+            shap_report["eval_metric"] = (
+                shap_report["val_metric_mean"] - shap_report["val_metric_std"] * standard_error_threshold
+            )
+            best_iteration_idx = shap_report["eval_metric"].argmax()
+            # Find standard error threshold above which we want to focus
+            best_val_metric_threshold = shap_report["eval_metric"].iloc[best_iteration_idx]
+            # Drop iterations with val_metric below threshold
+            shap_report = shap_report[shap_report["val_metric_mean"] >= best_val_metric_threshold]
+            # Get iteration with smallest num_features
+            best_parsimonious_iteration_idx = shap_report["num_features"].argmin()
+            best_num_features = shap_report["num_features"].iloc[best_parsimonious_iteration_idx]
+
+        else:
+            raise ValueError(
+                "The parameter best_method can take values of 'best', 'best_coherent' or 'best_parsimonious'"
+            )
+
+        # Log shap_report for users who want to inspect / debug
+        if self.verbose > 50:
+            print(shap_report)
+
+        return best_num_features
+
+    def _get_feature_names(self, num_features):
+        """
+        Helper function that takes num_features and returns the associated list of column/feature names.
+
+        Args:
+            num_features (int):
+                Represents the top N features to get the column names for.
+
+        Returns:
+            (list of feature names)
+                List of the names of the features representing top num_features
+        """
+        self._check_if_fitted()
         if num_features not in self.report_df.num_features.tolist():
             raise (
                 ValueError(
@@ -682,6 +865,50 @@ class ShapRFECV(BaseFitComputePlotClass):
         else:
             return self.report_df[self.report_df.num_features == num_features]["features_set"].values[0]
 
+    def _get_feature_support(self, feature_names_selected):
+        """
+        Helper function that takes feature_names_selected and returns a boolean mask representing the columns
+        that were selected by the RFECV method.
+
+        Args:
+            feature_names_selected (list):
+                Represents the top N features to get the column names for.
+
+        Returns:
+            (list of bools)
+                Boolean mask representing the features selected.
+        """
+        support = [True if col in feature_names_selected else False for col in self.column_names]
+        return support
+
+    def _get_feature_ranking(self):
+        """
+        Returns the feature ranking, such that ranking_[i] corresponds to the ranking position
+        of the i-th feature. Selected (i.e., estimated best) features are assigned rank 1.
+
+        Returns:
+            (list of bools)
+                Boolean mask representing the features selected.
+        """
+
+        flipped_report_df = self.report_df.iloc[::-1]
+
+        # Some features are not eliminated. All have importance of zero (highest importance)
+        features_not_eliminated = flipped_report_df["features_set"].iloc[0]
+        features_not_eliminated_dict = {v: 0 for v in features_not_eliminated}
+
+        # Eliminated features are ranked by shap importance
+        features_eliminated = np.concatenate(flipped_report_df["eliminated_features"].to_numpy())
+        features_eliminated_dict = {int(v): k + 1 for (k, v) in enumerate(features_eliminated)}
+
+        # Combine dicts with rank info
+        features_eliminated_dict.update(features_not_eliminated_dict)
+
+        # Get ranking per the order of columns
+        ranking = [features_eliminated_dict[col] for col in self.column_names]
+
+        return ranking
+
     def plot(self, show=True, **figure_kwargs):
         """
         Generates plot of the model performance for each iteration of feature elimination.
@@ -700,7 +927,7 @@ class ShapRFECV(BaseFitComputePlotClass):
         """
         x_ticks = list(reversed(self.report_df["num_features"].tolist()))
 
-        plt.figure(**figure_kwargs)
+        fig = plt.figure(**figure_kwargs)
 
         plt.plot(
             self.report_df["num_features"],
@@ -730,14 +957,13 @@ class ShapRFECV(BaseFitComputePlotClass):
         plt.ylabel(f"Performance {self.scorer.metric_name}")
         plt.title("Backwards Feature Elimination using SHAP & CV")
         plt.legend(loc="lower left")
-        ax = plt.gca()
-        ax.invert_xaxis()
-        ax.set_xticks(x_ticks)
+        fig.axes[0].invert_xaxis()
+        fig.axes[0].set_xticks(x_ticks)
         if show:
             plt.show()
         else:
             plt.close()
-        return ax
+        return fig
 
 
 class EarlyStoppingShapRFECV(ShapRFECV):
@@ -861,7 +1087,7 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             min_features_to_select (int, optional):
                 Minimum number of features to be kept. This is a stopping criterion of the feature elimination. By
                 default the process stops when one feature is left. If columns_to_keep is specified in the fit method,
-                it may overide this parameter to the maximum between length of columns_to_keep the two.
+                it may override this parameter to the maximum between length of columns_to_keep the two.
 
             cv (int, cross-validation generator or an iterable, optional):
                 Determines the cross-validation splitting strategy. Compatible with sklearn
@@ -902,7 +1128,7 @@ class EarlyStoppingShapRFECV(ShapRFECV):
                  and [LightGBM](https://lightgbm.readthedocs.io/en/latest/Parameters.html#metric-parameters).
                 Note that `eval_metric` is an argument of the model's fit method and it is different from `scoring`.
         """  # noqa
-        super(EarlyStoppingShapRFECV, self).__init__(
+        super().__init__(
             clf,
             step=step,
             min_features_to_select=min_features_to_select,
@@ -978,7 +1204,6 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             "X": X_train,
             "y": y_train,
             "eval_set": [(X_val, y_val)],
-            "eval_metric": self.eval_metric,
             "callbacks": [early_stopping(self.early_stopping_rounds, first_metric_only=True)],
         }
         if self.verbose >= 100:
@@ -1032,8 +1257,6 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             "X": X_train,
             "y": y_train,
             "eval_set": [(X_val, y_val)],
-            "eval_metric": self.eval_metric,
-            "early_stopping_rounds": self.early_stopping_rounds,
         }
         if sample_weight is not None:
             fit_params["sample_weight"] = sample_weight.iloc[train_index]
@@ -1084,7 +1307,6 @@ class EarlyStoppingShapRFECV(ShapRFECV):
         fit_params = {
             "X": Pool(X_train, y_train, cat_features=cat_features),
             "eval_set": Pool(X_val, y_val, cat_features=cat_features),
-            "early_stopping_rounds": self.early_stopping_rounds,
             # Evaluation metric should be passed during initialization
         }
         if sample_weight is not None:
@@ -1237,6 +1459,32 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             val_index=val_index,
         )
 
+        # Due to deprecation issues (compatibility with Sklearn) set some params
+        # like below, instead of through fit().
+        try:
+            from lightgbm import LGBMModel
+
+            if isinstance(clf, LGBMModel):
+                clf.set_params(eval_metric=self.eval_metric)
+        except ImportError:
+            pass
+
+        try:
+            from xgboost.sklearn import XGBModel
+
+            if isinstance(clf, XGBModel):
+                clf.set_params(eval_metric=self.eval_metric, early_stopping_rounds=self.early_stopping_rounds)
+        except ImportError:
+            pass
+
+        try:
+            from catboost import CatBoost
+
+            if isinstance(clf, CatBoost):
+                clf.set_params(early_stopping_rounds=self.early_stopping_rounds)
+        except ImportError:
+            pass
+
         # Train the model
         clf = clf.fit(**fit_params)
 
