@@ -18,21 +18,22 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
+import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
+from shap import summary_plot
+from shap.plots._waterfall import waterfall_legacy
+
 from probatus.interpret import DependencePlotter
 from probatus.utils import (
+    BaseFitComputePlotClass,
+    assure_list_of_strings,
+    calculate_shap_importance,
+    get_single_scorer,
     preprocess_data,
     preprocess_labels,
     shap_calc,
-    calculate_shap_importance,
-    BaseFitComputePlotClass,
-    assure_list_of_strings,
-    get_single_scorer,
 )
-import numpy as np
-from shap import summary_plot
-from shap.plots._waterfall import waterfall_legacy
-import matplotlib.pyplot as plt
-import pandas as pd
 
 
 class ShapModelInterpreter(BaseFitComputePlotClass):
@@ -105,7 +106,17 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
         self.scorer = get_single_scorer(scoring)
         self.verbose = verbose
 
-    def fit(self, X_train, X_test, y_train, y_test, column_names=None, class_names=None, **shap_kwargs):
+    def fit(
+        self,
+        X_train,
+        X_test,
+        y_train,
+        y_test,
+        column_names=None,
+        class_names=None,
+        shap_variance_penalty_factor=None,
+        **shap_kwargs,
+    ):
         """
         Fits the object and calculates the shap values for the provided datasets.
 
@@ -129,6 +140,12 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
                 List of class names e.g. ['neg', 'pos']. If none, the default ['Negative Class', 'Positive Class'] are
                 used.
 
+            shap_variance_penalty_factor (int or float, optional):
+                Apply aggregation penalty when computing average of shap values for a given feature.
+                Results in a preference for features that have smaller standard deviation of shap
+                values (more coherent shap importance). Recommend value 0.5 - 1.0.
+                Formula: penalized_shap_mean = (mean_shap - (std_shap * shap_variance_penalty_factor))
+
             **shap_kwargs:
                 keyword arguments passed to
                 [shap.Explainer](https://shap.readthedocs.io/en/latest/generated/shap.Explainer.html#shap.Explainer).
@@ -158,7 +175,11 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
             f"Test {self.scorer.metric_name}: {np.round(self.test_score, 3)}."
         )
 
-        (self.shap_values_train, self.expected_value_train, self.tdp_train,) = self._prep_shap_related_variables(
+        (
+            self.shap_values_train,
+            self.expected_value_train,
+            self.tdp_train,
+        ) = self._prep_shap_related_variables(
             clf=self.clf,
             X=self.X_train,
             y=self.y_train,
@@ -168,7 +189,11 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
             **shap_kwargs,
         )
 
-        (self.shap_values_test, self.expected_value_test, self.tdp_test,) = self._prep_shap_related_variables(
+        (
+            self.shap_values_test,
+            self.expected_value_test,
+            self.tdp_test,
+        ) = self._prep_shap_related_variables(
             clf=self.clf,
             X=self.X_test,
             y=self.y_test,
@@ -223,7 +248,7 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
         )
         return shap_values, expected_value, tdp
 
-    def compute(self, return_scores=False):
+    def compute(self, return_scores=False, shap_variance_penalty_factor=None):
         """
         Computes the DataFrame that presents the importance of each feature.
 
@@ -233,6 +258,12 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
                 the model interpretation report. If true, the output of this method is a tuple of DataFrame, float,
                 float.
 
+            shap_variance_penalty_factor (int or float, optional):
+                Apply aggregation penalty when computing average of shap values for a given feature.
+                Results in a preference for features that have smaller standard deviation of shap
+                values (more coherent shap importance). Recommend value 0.5 - 1.0.
+                Formula: penalized_shap_mean = (mean_shap - (std_shap * shap_variance_penalty_factor))
+
         Returns:
             (pd.DataFrame or tuple(pd.DataFrame, float, float)):
                 Dataframe with SHAP feature importance, or tuple containing the dataframe, train and test scores of the
@@ -242,11 +273,17 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
 
         # Compute SHAP importance
         self.importance_df_train = calculate_shap_importance(
-            self.shap_values_train, self.column_names, output_columns_suffix="_train"
+            self.shap_values_train,
+            self.column_names,
+            output_columns_suffix="_train",
+            shap_variance_penalty_factor=shap_variance_penalty_factor,
         )
 
         self.importance_df_test = calculate_shap_importance(
-            self.shap_values_test, self.column_names, output_columns_suffix="_test"
+            self.shap_values_test,
+            self.column_names,
+            output_columns_suffix="_test",
+            shap_variance_penalty_factor=shap_variance_penalty_factor,
         )
 
         # Concatenate the train and test, sort by test set importance and reorder the columns
@@ -275,6 +312,7 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
         column_names=None,
         class_names=None,
         return_scores=False,
+        shap_variance_penalty_factor=None,
         **shap_kwargs,
     ):
         """
@@ -309,6 +347,12 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
                 the output of this method is a tuple of DataFrame, float,
                 float.
 
+            shap_variance_penalty_factor (int or float, optional):
+                Apply aggregation penalty when computing average of shap values for a given feature.
+                Results in a preference for features that have smaller standard deviation of shap
+                values (more coherent shap importance). Recommend value 0.5 - 1.0.
+                Formula: penalized_shap_mean = (mean_shap - (std_shap * shap_variance_penalty_factor))
+
             **shap_kwargs:
                 keyword arguments passed to
                 [shap.Explainer](https://shap.readthedocs.io/en/latest/generated/shap.Explainer.html#shap.Explainer).
@@ -328,9 +372,10 @@ class ShapModelInterpreter(BaseFitComputePlotClass):
             y_test=y_test,
             column_names=column_names,
             class_names=class_names,
+            shap_variance_penalty_factor=shap_variance_penalty_factor,
             **shap_kwargs,
         )
-        return self.compute()
+        return self.compute(shap_variance_penalty_factor=shap_variance_penalty_factor)
 
     def plot(self, plot_type, target_set="test", target_columns=None, samples_index=None, show=True, **plot_kwargs):
         """
