@@ -1,16 +1,16 @@
 import numpy as np
 import pandas as pd
-
 import pytest
+from packaging import version
 
 from probatus.utils import (
+    DimensionalityError,
     assure_numpy_array,
     assure_pandas_df,
     check_1d,
-    DimensionalityError,
     check_numeric_dtypes,
-    preprocess_labels,
     preprocess_data,
+    preprocess_labels,
 )
 
 
@@ -105,10 +105,16 @@ def test_check_1d_array():
     """
     x = np.array([1, 2, 3])
     assert check_1d(x)
-    y = np.array([[1, 2], [1, 2, 3]])
+    if version.parse(np.__version__) < version.parse("1.24.0"):
+        y = np.array([[1, 2], [1, 2, 3]])
+    else:
+        y = np.array([[1, 2], [1, 2, 3]], dtype=object)
     with pytest.raises(DimensionalityError):
         assert check_1d(y)
-    y = np.array([0, [1, 2, 3]])
+    if version.parse(np.__version__) < version.parse("1.24.0"):
+        y = np.array([0, [1, 2, 3]])
+    else:
+        y = np.array([0, [1, 2, 3]], dtype=object)
     with pytest.raises(DimensionalityError):
         assert check_1d(y)
 
@@ -219,37 +225,21 @@ def test_preprocess_labels():
     y1 = pd.Series([1, 0, 1, 0, 1])
     index_1 = np.array([5, 4, 3, 2, 1])
 
-    with pytest.warns(None) as record:
-        y1_output = preprocess_labels(y1, y_name="y1", index=index_1, verbose=150)
-
+    y1_output = preprocess_labels(y1, y_name="y1", index=index_1, verbose=150)
     pd.testing.assert_series_equal(y1_output, pd.Series([1, 0, 1, 0, 1], index=index_1))
-    # Ensure that number of warnings is correct
-    assert len(record) == 0
 
     y2 = [False, False, False, False, False]
-
-    with pytest.warns(None) as record:
-        y2_output = preprocess_labels(y2, y_name="y2", verbose=150)
-
+    y2_output = preprocess_labels(y2, y_name="y2", verbose=150)
     pd.testing.assert_series_equal(y2_output, pd.Series(y2))
-    # Ensure that number of warnings is correct
-    assert len(record) == 1
 
     y3 = np.array([0, 1, 2, 3, 4])
-    with pytest.warns(None) as record:
-        y3_output = preprocess_labels(y3, y_name="y3", verbose=150)
-
+    y3_output = preprocess_labels(y3, y_name="y3", verbose=150)
     pd.testing.assert_series_equal(y3_output, pd.Series(y3))
-    # Ensure that number of warnings is correct
-    assert len(record) == 1
 
     y4 = pd.Series(["2", "1", "3", "2", "1"])
     index4 = pd.Index([0, 2, 1, 3, 4])
-    with pytest.warns(None) as record:
-        y4_output = preprocess_labels(y4, y_name="y4", index=index4, verbose=0)
+    y4_output = preprocess_labels(y4, y_name="y4", index=index4, verbose=0)
     pd.testing.assert_series_equal(y4_output, pd.Series(["2", "3", "1", "2", "1"], index=index4))
-    # Ensure that number of warnings is correct
-    assert len(record) == 0
 
 
 def test_preprocess_data():
@@ -262,26 +252,17 @@ def test_preprocess_data():
     X1_expected_output = pd.DataFrame({"1": ["a", "b", "c"], "2": [1, np.nan, 2], "3": [1, 2, 3]})
 
     X1_expected_output["1"] = X1_expected_output["1"].astype("category")
-
-    with pytest.warns(None) as record:
-        X1_output, output_column_names_X1 = preprocess_data(
-            X1, X_name="X1", column_names=target_column_names_X1, verbose=150
-        )
-
+    X1_output, output_column_names_X1 = preprocess_data(
+        X1, X_name="X1", column_names=target_column_names_X1, verbose=150
+    )
     assert target_column_names_X1 == output_column_names_X1
     pd.testing.assert_frame_equal(X1_output, X1_expected_output)
-    # Ensure that number of warnings is correct
-    assert len(record) == 2
 
     X2 = np.array([[1, 3, 2], [1, 2, 2], [1, 2, 3]])
 
     target_column_names_X1 = [0, 1, 2]
     X2_expected_output = pd.DataFrame(X2, columns=target_column_names_X1)
-
-    with pytest.warns(None) as record:
-        X2_output, output_column_names_X2 = preprocess_data(X2, X_name="X2", column_names=None, verbose=150)
+    X2_output, output_column_names_X2 = preprocess_data(X2, X_name="X2", column_names=None, verbose=150)
 
     assert target_column_names_X1 == output_column_names_X2
     pd.testing.assert_frame_equal(X2_output, X2_expected_output)
-    # Ensure that number of warnings is correct
-    assert len(record) == 0
